@@ -2,6 +2,7 @@ import logging
 
 from lxml import html
 from requests import exceptions
+import simplejson
 
 from . import helpers
 from . import util
@@ -128,6 +129,14 @@ class Message(object):
             content = message.text_content().replace(' \n \n', '\n').strip()
         return content
 
+    _timestamp_xpb = xpb.span.with_class('timestamp').span.with_class('fancydate')
+    @util.cached_property
+    def time_sent(self):
+        fancydate_text = self._timestamp_xpb.select_attribute_(
+            'id', self._message_element
+        )[0]
+        return helpers.parse_fancydate(fancydate_text)
+
     def __repr__(self):
         return '<{0}: {1} sent {2} "{3}{4}">'.format(
             type(self).__name__,
@@ -141,6 +150,14 @@ class Message(object):
 class MessageThread(object):
     """Represent a message thread between two users."""
 
+    @classmethod
+    def delete_threads(cls, session, thread_ids, authcode=None):
+        if not authcode:
+            authcode = helpers.get_authcode(html.fromstring(session.okc_get('messages').content))
+        data = {'access_token': authcode,
+                'threadids': simplejson.dumps(thread_ids)}
+        return session.okc_delete('apitun/messages/threads', params=data, data=data)
+
     def __init__(self, session, thread_element):
         self._session = session
         self._thread_element = thread_element
@@ -162,7 +179,13 @@ class MessageThread(object):
         """
         :returns: The id assigned to the correspondent of this message.
         """
-        return self._thread_element['data-personid']
+        try:
+            return int(self._thread_element.attrib['data-personid'])
+        except (ValueError, KeyError):
+            try:
+                return int(self.correspondent_profile.id)
+            except:
+                pass
 
     _correspondent_xpb = xpb.div.with_class('inner').a.with_class('photo').\
                              img.select_attribute_('alt')
@@ -187,15 +210,13 @@ class MessageThread(object):
     def date(self):
         return self.datetime.date()
 
+    _timestamp_xpb = xpb.span.with_class('timestamp').span.with_class('fancydate')
     @util.cached_property
     def datetime(self):
-        """
-        :returns: The datetime at which this :class:`~.MessageThread`. was last
-                  updated.
-        """
-        timestamp_span = xpb.span.with_class('timestamp').apply_(self._thread_element)
-        date_updated_text = timestamp_span[0][0].text_content()
-        return helpers.parse_date_updated(date_updated_text)
+        fancydate_text = self._timestamp_xpb.select_attribute_(
+            'id', self._thread_element
+        )[0]
+        return helpers.parse_fancydate(fancydate_text)
 
     @property
     def with_deleted_user(self):
@@ -262,21 +283,7 @@ class MessageThread(object):
 
     def delete(self):
         """Delete this thread for the logged in user."""
-        return self._session.post('https://www.okcupid.com/mailbox',
-                                  params=self.delete_params)
-
-    @property
-    def delete_params(self):
-        return {
-            'deletethread': 'DELETE',
-            'mailaction': 3,
-            'buddyname': self.correspondent,
-            'r1': self.correspondent,
-            'threadid': self.id,
-            'receiverid': self.correspondent_id,
-            'folderid': 1,
-            'body_to_forward': self.messages[-1].content
-        }
+        return self.delete_threads(self._session, [self.id])
 
     def __hash__(self):
         return hash(self.id)
